@@ -47,9 +47,9 @@ bool PossibleMove::isInPath(int x, int y) const
     }
     qCDebug(KSHISEN_LOG) << "isInPath:" << x << "," << y;
     Debug();
-    QList<Position>::const_iterator iter;
+
     // a path has at least 2 positions
-    iter = m_path.constBegin();
+    auto iter = m_path.constBegin();
     int pathX = iter->x;
     int pathY = iter->y;
     ++iter;
@@ -69,15 +69,15 @@ bool PossibleMove::isInPath(int x, int y) const
 Board::Board(QWidget *parent)
     : QWidget(parent),
       m_markX(0), m_markY(0),
-      m_field(0),
+      m_field(nullptr),
       m_xTiles(0), m_yTiles(0),
       m_delay(0), m_level(0), m_shuffle(0),
-      m_gameState(Normal), m_cheat(false),
+      m_gameState(GameState::Normal), m_cheat(false),
       m_gravityFlag(true), m_solvableFlag(false), m_chineseStyleFlag(false), m_tilesCanSlideFlag(false),
       m_highlightedTile(-1),
       m_paintConnection(false), m_paintPossibleMoves(false), m_paintInProgress(false),
-      m_soundPick(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("sounds/kshisen/tile-touch.ogg"))),
-      m_soundFall(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("sounds/kshisen/tile-fall-tile.ogg")))
+      m_soundPick(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("sounds/kshisen/tile-touch.ogg"))),
+      m_soundFall(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("sounds/kshisen/tile-fall-tile.ogg")))
 {
     m_tileRemove1.first = -1;
 
@@ -287,15 +287,15 @@ void Board::mousePressEvent(QMouseEvent *e)
         return;
     }
     switch (m_gameState) {
-        case Normal:
+        case GameState::Normal:
             break;
-        case Over:
+        case GameState::Over:
             newGame();
             return;
-        case Paused:
+        case GameState::Paused:
             setPauseEnabled(false);
             return;
-        case Stuck:
+        case GameState::Stuck:
             return;
     }
     // Calculate field position
@@ -398,7 +398,7 @@ void Board::setSize(int x, int y)
     int w = qRound(m_tiles.qWidth() * 2.0 * MINIMUM_SCALE) * xTiles();
     int h = qRound(m_tiles.qHeight() * 2.0 * MINIMUM_SCALE) * yTiles();
     w += m_tiles.width();
-    h += m_tiles.width();
+    h += m_tiles.height();
 
     setMinimumSize(w, h);
 
@@ -433,7 +433,7 @@ void Board::resizeBoard()
 
 void Board::newGame()
 {
-    m_gameState = Normal;
+    m_gameState = GameState::Normal;
     setCheatModeEnabled(false);
 
     m_markX = -1;
@@ -681,17 +681,17 @@ void Board::paintEvent(QPaintEvent *e)
     p.fillRect(ur, m_background.getBackground());
 
     switch (m_gameState) {
-        case Normal:
+        case GameState::Normal:
             drawTiles(p, e);
             break;
-        case Paused:
+        case GameState::Paused:
             showInfoRect(p, i18n("Game Paused\nClick to resume game."));
             break;
-        case Stuck:
+        case GameState::Stuck:
             drawTiles(p, e);
             showInfoRect(p, i18n("Game Stuck\nNo more moves possible."));
             break;
-        case Over:
+        case GameState::Over:
             showInfoRect(p, i18n("Game Over\nClick to start a new game."));
             break;
     }
@@ -699,23 +699,23 @@ void Board::paintEvent(QPaintEvent *e)
     if (m_paintConnection) {
         p.setPen(QPen(QColor("red"), lineWidth()));
 
-        Path::const_iterator pt1 = m_connection.constBegin();
-        Path::const_iterator pt2 = pt1 + 1;
+        auto pt1 = m_connection.constBegin();
+        auto pt2 = pt1 + 1;
         while (pt2 != m_connection.constEnd()) {
             p.drawLine(midCoord(pt1->x, pt1->y), midCoord(pt2->x, pt2->y));
             ++pt1;
             ++pt2;
         }
-        QTimer::singleShot(delay(), this, SLOT(undrawConnection()));
+        QTimer::singleShot(delay(), this, &Board::undrawConnection);
         m_paintConnection = false;
     }
     if (m_paintPossibleMoves) {
         p.setPen(QPen(QColor("blue"), lineWidth()));
         // paint all possible moves
-        for (QList<PossibleMove>::const_iterator iter = m_possibleMoves.constBegin(); iter != m_possibleMoves.constEnd(); ++iter) {
-            Path::const_iterator pt1 = iter->m_path.constBegin();
-            Path::const_iterator pt2 = pt1 + 1;
-            while (pt2 != iter->m_path.constEnd()) {
+        for (auto const move : m_possibleMoves) {
+            auto pt1 = move.m_path.constBegin();
+            auto pt2 = pt1 + 1;
+            while (pt2 != move.m_path.constEnd()) {
                 p.drawLine(midCoord(pt1->x, pt1->y), midCoord(pt2->x, pt2->y));
                 ++pt1;
                 ++pt2;
@@ -923,9 +923,9 @@ void Board::marked(int x, int y)
 {
     if (field(x, y) == EMPTY) { // click on empty space on the board
         if (m_possibleMoves.count() > 1) {  // if the click is on any of the current possible moves, make that move
-            for (QList<PossibleMove>::iterator iter = m_possibleMoves.begin(); iter != m_possibleMoves.end(); ++iter) {
-                if (iter->isInPath(x, y)) {
-                    performMove(*iter);
+            for (auto move : m_possibleMoves) {
+                if (move.isInPath(x, y)) {
+                    performMove(move);
                     emit selectATile();
                     return;
                 }
@@ -960,9 +960,9 @@ void Board::marked(int x, int y)
         return;
     } else if (m_possibleMoves.count() > 1) {  // if the click is on any of the current possible moves, make that move
 
-        for (QList<PossibleMove>::iterator iter = m_possibleMoves.begin(); iter != m_possibleMoves.end(); ++iter) {
-            if (iter->isInPath(x, y)) {
-                performMove(*iter);
+        for (auto move : m_possibleMoves) {
+            if (move.isInPath(x, y)) {
+                performMove(move);
                 emit selectATile();
                 return;
             }
@@ -983,9 +983,9 @@ void Board::marked(int x, int y)
     if (findPath(m_markX, m_markY, x, y, m_possibleMoves) > 0) {
         if (m_possibleMoves.count() > 1) {
             int withSlide = 0;
-            for (QList<PossibleMove>::const_iterator iter = m_possibleMoves.constBegin(); iter != m_possibleMoves.constEnd(); ++iter) {
-                iter->Debug();
-                if (iter->m_hasSlide) {
+            for (auto const move : m_possibleMoves) {
+                move.Debug();
+                if (move.m_hasSlide) {
                     ++withSlide;
                 }
             }
@@ -1370,8 +1370,8 @@ void Board::undrawConnection()
     m_connection.clear();
     m_paintConnection = false;
 
-    Path::const_iterator pt1 = oldConnection.constBegin();
-    Path::const_iterator pt2 = pt1 + 1;
+    auto pt1 = oldConnection.constBegin();
+    auto pt2 = pt1 + 1;
     while (pt2 != oldConnection.constEnd()) {
         if (pt1->y == pt2->y) {
             for (int i = qMin(pt1->x, pt2->x); i <= qMax(pt1->x, pt2->x); ++i) {
@@ -1737,9 +1737,9 @@ void Board::dumpBoard() const
         for (int x = 0; x < xTiles(); ++x) {
             int tile = field(x, y);
             if (tile == EMPTY) {
-                row += " --";
+                row += QLatin1String(" --");
             } else {
-                row += QString("%1").arg(tile, 3);
+                row += QString(QLatin1String("%1")).arg(tile, 3);
             }
         }
         qCDebug(KSHISEN_LOG) << row;
@@ -1754,9 +1754,9 @@ void Board::dumpBoard(const int *board) const
         for (int x = 0; x < xTiles(); ++x) {
             int tile = board[y * xTiles() + x];
             if (tile == EMPTY) {
-                row += " --";
+                row += QLatin1String(" --");
             } else {
-                row += QString("%1").arg(tile, 3);
+                row += QString(QLatin1String("%1")).arg(tile, 3);
             }
         }
         qCDebug(KSHISEN_LOG) << row;
@@ -1916,14 +1916,14 @@ void Board::setTilesCanSlideFlag(bool enabled)
 
 void Board::setPauseEnabled(bool enabled)
 {
-    if ((m_gameState == Paused && enabled) || m_gameState == Stuck) {
+    if ((m_gameState == GameState::Paused && enabled) || m_gameState == GameState::Stuck) {
         return;
     }
     if (enabled) {
-        m_gameState = Paused;
+        m_gameState = GameState::Paused;
         m_gameClock.pause();
     } else {
-        m_gameState = Normal;
+        m_gameState = GameState::Normal;
         m_gameClock.resume();
     }
     emit changed();
@@ -1964,14 +1964,14 @@ void Board::resetRedo()
 
 void Board::setGameStuckEnabled(bool enabled)
 {
-    if (m_gameState == Stuck && enabled) {
+    if (m_gameState == GameState::Stuck && enabled) {
         return;
     }
     if (enabled) {
-        m_gameState = Stuck;
+        m_gameState = GameState::Stuck;
         m_gameClock.pause();
     } else {
-        m_gameState = Normal;
+        m_gameState = GameState::Normal;
         m_gameClock.resume();
     }
     emit changed();
@@ -1980,10 +1980,10 @@ void Board::setGameStuckEnabled(bool enabled)
 
 void Board::setGameOverEnabled(bool enabled)
 {
-    if (m_gameState == Over && enabled) {
+    if (m_gameState == GameState::Over && enabled) {
         return;
     }
-    m_gameState = Over;
+    m_gameState = GameState::Over;
     emit changed();
     update();
 }
@@ -1999,17 +1999,17 @@ void Board::setCheatModeEnabled(bool enabled)
 
 bool Board::isOver() const
 {
-    return m_gameState == Over;
+    return m_gameState == GameState::Over;
 }
 
 bool Board::isPaused() const
 {
-    return m_gameState == Paused;
+    return m_gameState == GameState::Paused;
 }
 
 bool Board::isStuck() const
 {
-    return m_gameState == Stuck;
+    return m_gameState == GameState::Stuck;
 }
 
 bool Board::hasCheated() const
